@@ -24,7 +24,6 @@
 #include "layout/htmlbox.h"
 #include "layout/htmlboxtext.h"
 #include "layout/html/htmlboxform.h"
-#include "layout/html/htmlboximage.h"
 #include "layout/htmlboxinline.h"
 #include "layout/htmlboxtablerow.h"
 #include "gtkhtmlcontext.h"
@@ -151,13 +150,17 @@ simple_margin (HtmlStyle *style)
 static gboolean
 need_containing_width (HtmlBox *box, gint width)
 {
+	HtmlStyle *style;
+
 	if (width > 0)
 		return FALSE;
 
-	if (html_box_get_containing_block (box))
-		return TRUE;
+	style = HTML_BOX_GET_STYLE (box);
 
-	return FALSE;
+	if (simple_margin (style))
+		return FALSE;
+
+	return TRUE;
 }
 
 gint
@@ -304,7 +307,7 @@ html_box_left_margin (HtmlBox *box, gint width)
 	else if (style->surround->margin.left.type != HTML_LENGTH_AUTO &&
 		 style->surround->margin.right.type != HTML_LENGTH_AUTO) {
 
-		if (HTML_BOX_GET_STYLE (html_box_get_containing_block (box))->inherited->direction == HTML_DIRECTION_RTL) {
+		if (HTML_BOX_GET_STYLE (box->parent)->inherited->direction == HTML_DIRECTION_RTL) {
 
 			return width - html_length_get_value (&style->box->width, width) -
 				html_box_left_padding (box, width) - html_box_right_padding (box, width) -
@@ -344,7 +347,7 @@ html_box_right_margin (HtmlBox *box, gint width)
 	else if (style->surround->margin.left.type != HTML_LENGTH_AUTO &&
 		 style->surround->margin.right.type != HTML_LENGTH_AUTO) {
 
-		if (HTML_BOX_GET_STYLE (html_box_get_containing_block (box))->inherited->direction == HTML_DIRECTION_LTR) {
+		if (HTML_BOX_GET_STYLE (box->parent)->inherited->direction == HTML_DIRECTION_LTR) {
 
 			return width - html_length_get_value (&style->box->width, width) -
 				html_box_left_padding (box, width) - html_box_right_padding (box, width) -
@@ -449,9 +452,6 @@ html_box_finalize (GObject *object)
 	if (box->style)
 		html_style_unref (box->style);
 
-	if (box->dom_node)
-		g_object_remove_weak_pointer (G_OBJECT (box->dom_node), (gpointer *) &(box->dom_node));
-
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 	
 }
@@ -814,38 +814,35 @@ void
 html_box_check_min_max_width_height (HtmlBox *self, gint *boxwidth, gint *boxheight) 
 {
 	int tmp;
-	gint old_width = *boxwidth;
-	gint old_height = *boxheight;
-	HtmlBox *parent = html_box_get_containing_block (self);
 
-	if (parent) {
+	if (self->parent) {
 		if (HTML_BOX_GET_STYLE (self)->box->min_width.type != HTML_LENGTH_AUTO) {
-			tmp = html_length_get_value (&HTML_BOX_GET_STYLE (self)->box->min_width, parent->width -
-						     html_box_horizontal_mbp_sum (parent) - html_box_horizontal_mbp_sum (self));
+			tmp = html_length_get_value (&HTML_BOX_GET_STYLE (self)->box->min_width, self->parent->width -
+						     html_box_horizontal_mbp_sum (self->parent) - html_box_horizontal_mbp_sum (self));
 			if (*boxwidth < tmp)
 				*boxwidth = tmp;		
 
 		}
 		
 		if (HTML_BOX_GET_STYLE (self)->box->max_width.type != HTML_LENGTH_AUTO) {
-			tmp = html_length_get_value (&HTML_BOX_GET_STYLE (self)->box->max_width, parent->width -
-						     html_box_horizontal_mbp_sum (parent) - html_box_horizontal_mbp_sum (self));
+			tmp = html_length_get_value (&HTML_BOX_GET_STYLE (self)->box->max_width, self->parent->width -
+						     html_box_horizontal_mbp_sum (self->parent) - html_box_horizontal_mbp_sum (self));
 			if (*boxwidth > tmp)
 				*boxwidth = tmp;		
 
 		}
 		
 		if (HTML_BOX_GET_STYLE (self)->box->min_height.type != HTML_LENGTH_AUTO) {
-			tmp = html_length_get_value (&HTML_BOX_GET_STYLE (self)->box->min_height, parent->height -
-						     html_box_horizontal_mbp_sum (parent) - html_box_horizontal_mbp_sum (self));
+			tmp = html_length_get_value (&HTML_BOX_GET_STYLE (self)->box->min_height, self->parent->height -
+						     html_box_horizontal_mbp_sum (self->parent) - html_box_horizontal_mbp_sum (self));
 			if (*boxheight < tmp)
 				*boxheight = tmp;		
 
 		}
 		
 		if (HTML_BOX_GET_STYLE (self)->box->max_height.type != HTML_LENGTH_AUTO) {
-			tmp = html_length_get_value (&HTML_BOX_GET_STYLE (self)->box->max_height, parent->height -
-						     html_box_horizontal_mbp_sum (parent) - html_box_horizontal_mbp_sum (self));
+			tmp = html_length_get_value (&HTML_BOX_GET_STYLE (self)->box->max_height, self->parent->height -
+						     html_box_horizontal_mbp_sum (self->parent) - html_box_horizontal_mbp_sum (self));
 			if (*boxheight > tmp)
 				*boxheight = tmp;		
 
@@ -868,26 +865,6 @@ html_box_check_min_max_width_height (HtmlBox *self, gint *boxwidth, gint *boxhei
 			if (*boxheight > html_length_get_value (&HTML_BOX_GET_STYLE (self)->box->max_height, 0))
 				*boxheight = html_length_get_value (&HTML_BOX_GET_STYLE (self)->box->max_height, 0);
 	}
-	
-	/* Maintain aspect ratio if it's an image */
-	if (HTML_IS_BOX_IMAGE (self)) {
-		if ((*boxwidth > old_width) && (*boxheight >= old_height)) {
-			*boxheight = *boxheight * (gdouble)(*boxwidth / (gdouble)old_width);
-			return;
-		}
-		else if ((*boxheight > old_height) && (*boxwidth >= old_width)) {
-			*boxwidth = *boxwidth * (gdouble)(*boxheight / (gdouble)old_height);
-			return;
-		}
-		else if ((*boxwidth < old_width) && (*boxheight <= old_height)) {
-			*boxheight = *boxheight * (gdouble)(*boxwidth / (gdouble)old_width);
-			return;
-		}
-		else if ((*boxheight < old_height) && (*boxwidth <= old_width)) {
-			*boxwidth = *boxwidth * (gdouble)(*boxheight / (gdouble)old_height);
-			return;
-		}
-	}
 }
 
 static void
